@@ -3,25 +3,24 @@
  * is used. Pre-allocated memory is managed by a bit map.
  */
 
-#include <time.h>
 #include "whowatch.h"
 
 #define USED 		1
 #define NOT_USED	0
 #define TBL_SIZE	(sizeof(unsigned int)*8)
 
-static FILE *logfile;
-static int nr_blocks;
+//static int nr_blocks;
 
 void dolog(const char *t, ...)
 {
         va_list ap;
+	static FILE *logfile;
         char *c;
-        time_t tm = time(0);
-return;	
+        
+	time_t tm = time(0);
 	if(!logfile) {
 		logfile = fopen("/var/log/whowatch.log", "a");
-		if(!logfile) exit(1);
+		if(!logfile) return;
 		fprintf(logfile, " #############\n");
 	}
         c = ctime(&tm);
@@ -30,6 +29,7 @@ return;
         va_start(ap, t);
         vfprintf(logfile, t, ap);
         va_end(ap);
+	fprintf(logfile, "\n");
         fflush(logfile);
 }
 
@@ -43,11 +43,9 @@ static struct _block_tbl_t *new_block(int size, struct list_head *h)
 {
 	struct _block_tbl_t *tmp;
 	tmp = calloc(1, sizeof *tmp);
-	if(!tmp) prg_exit("new_block(): Cannot allocate memory. [1]\n");
+	if(!tmp) exit(0);
 	tmp->_block_t = calloc(1, size * TBL_SIZE);
-	dolog("%s: new block(%d) - alloc size = %d\n",
-		__FUNCTION__, nr_blocks, size * TBL_SIZE);
-	if(!tmp->_block_t) prg_exit("new_block(): Cannot allocate memory. [2]\n");
+	if(!tmp->_block_t) exit(0);
 	list_add(&tmp->head, h);
 	return tmp;
 }
@@ -70,31 +68,24 @@ int nr = 0;
 		}
 nr++;
 	}
-	dolog("%s: no empty space, getting new one.\n", __FUNCTION__);
 	tmp = new_block(size, h);
 	i = 0;
 FOUND:
-	dolog("%s: empty in %d block at %d pos\n", __FUNCTION__, nr, i);
 	tmp->map |= 1<<i;
 	return tmp->_block_t + (size * i);
 }
 
-#if 0
-/* dead code */
 /*
  * Free all unused blocks of memory (map == 0)
- */
 static void rm_free_blocks(struct list_head *head)
 {
 	struct _block_tbl_t *tmp;
 	struct list_head *t, *p;
 	t = head->next;
-	dolog("%s: entering\n", __FUNCTION__);
 	while(t != head) {
 		tmp = list_entry(t, struct _block_tbl_t, head);
 		p = t->next;
 		if(!tmp->map) {
-			dolog("%s: empty block found %p\n", __FUNCTION__, tmp);
 			free(tmp->_block_t);
 			list_del(&tmp->head);
 			free(tmp);
@@ -102,7 +93,7 @@ static void rm_free_blocks(struct list_head *head)
 		t = p;
 	}
 }
-#endif
+ */
 
 /*
  * Find entry pointed by p and mark it unused.
@@ -118,13 +109,9 @@ int i = 0;
 			goto FOUND;
 		i++;
 	}
-	dolog("%s: entry not found - error\n", __FUNCTION__);
 	return -1;
 FOUND:
-	dolog("%s: %p pointer found in %d\n", __FUNCTION__, p, i);
 	tmp->map &= ~(1<<(p - tmp->_block_t)/size);
-	dolog("%s: setting map pos %d to zero, map = %x\n",
-		__FUNCTION__, (p - tmp->_block_t)/size, tmp->map);
 	return 0;
 }		 	
 
